@@ -21,6 +21,7 @@ class ModelField(object):
         """
         """
 
+        self.name = None
         self.verbose_name = verbose_name
         self.help_text = help_text
         self.required = required
@@ -48,7 +49,7 @@ class ModelField(object):
         """
         """
 
-        pass
+        self.name = attribute_name
 
     def on_destroy(self, model_class):
         """
@@ -526,6 +527,7 @@ class ChoiceField(ModelField):
         for choice_pair in self.choices:
             if choice_pair[1] == self.choice_value:
                 has_match = True
+                break
 
         if not has_match:
             raise ChoiceField.WrongInputTypeException()
@@ -796,6 +798,8 @@ class ForeignKeyField(ModelField):
         """
         """
 
+        super(ForeignKeyField, self).on_init(model_class=model_class, attribute_name=attribute_name)
+
         # Set this only if there is a related name
         if self.related_name:
             fields = self.relation_class._model_meta_data._fields
@@ -885,6 +889,8 @@ class ManyToManyField(ModelField):
         """
         """
 
+        super(ManyToManyField, self).on_init(model_class=model_class, attribute_name=attribute_name)
+
         if not self.related_name is None:
             relation_name = self._get_relation_collection_name(model_class)
 
