@@ -20,16 +20,66 @@ class QueryFilterStatement(object):
         'lte': '<=',
     }
 
-    def __init__(self, collection, attribute, operator, value):
+    QUERY_FUNCTION_EXTENSIONS = ( 'contains', 'icontains', )
+
+    def __init__(self, collection, attribute, value, **kwargs):
         """
         """
 
         self.collection = collection
         self.attribute = attribute
-        self.operator = operator
+
+        if 'operator' in kwargs:
+            self.operator = kwargs['operator']
+        else:
+            self.operator = None
+
+        if 'function' in kwargs:
+            self.function = kwargs['function']
+        else:
+            self.function = None
+
         self.value = value
 
 
+    def get_filter_function_string(self, collection_name):
+        """
+        """
+
+        if self.function == 'contains':
+
+            filter_string = ' CONTAINS (%s.%s, %s) ' % (
+                        collection_name,
+                        self.attribute,
+                        self.get_value_string(),
+                    )
+
+        elif self.function == 'icontains':
+
+            filter_string = ' LIKE (%s.%s, "%s%s%s", true) ' % (
+                        collection_name,
+                        self.attribute,
+                        '%',
+                        self.value,
+                        '%',
+                    )
+
+        else:
+            filter_string = ''
+
+        return filter_string
+
+
+    def get_value_string(self):
+        """
+        """
+
+        if isinstance(self.value, basestring):
+            return '"%s"' % self.value
+        else:
+            return '%s' % self.value
+
+
 class QueryFilterContainer(object):
 
     def __init__(self, bit_operator):
@@ -178,9 +228,12 @@ class Query(object):
 
             if lenght_splitted_filter is 2:
 
-                if splitted_filter[1] in QueryFilterStatement.QUERY_CONDITION_EXTENSIONS:
+                second_filter_value = splitted_filter[1]
 
-                    operator = QueryFilterStatement.QUERY_CONDITION_EXTENSIONS[ splitted_filter[1] ]
+                # Is this a normal condition
+                if second_filter_value in QueryFilterStatement.QUERY_CONDITION_EXTENSIONS:
+
+                    operator = QueryFilterStatement.QUERY_CONDITION_EXTENSIONS[ second_filter_value ]
 
                     return QueryFilterStatement(
                         collection=self.collections[-1],
@@ -189,24 +242,48 @@ class Query(object):
                         value=filter_value,
                     )
 
+                # Is this a function condition
+                elif second_filter_value in QueryFilterStatement.QUERY_FUNCTION_EXTENSIONS:
+
+                    return QueryFilterStatement(
+                        collection=self.collections[-1],
+                        attribute=splitted_filter[0],
+                        function=second_filter_value,
+                        value=filter_value,
+                    )
+
+                # Just collection and attribute
                 else:
                     return QueryFilterStatement(
                         collection=splitted_filter[0],
-                        attribute=splitted_filter[1],
+                        attribute=second_filter_value,
                         operator=default_operator,
                         value=filter_value,
                     )
 
 
             else:
-                operator = QueryFilterStatement.QUERY_CONDITION_EXTENSIONS[ splitted_filter[2] ]
 
-                return QueryFilterStatement(
-                    collection=splitted_filter[0],
-                    attribute=splitted_filter[1],
-                    operator=operator,
-                    value=filter_value,
-                )
+
+                if splitted_filter[2] in QueryFilterStatement.QUERY_CONDITION_EXTENSIONS:
+                    operator = QueryFilterStatement.QUERY_CONDITION_EXTENSIONS[ splitted_filter[2] ]
+
+                    return QueryFilterStatement(
+                        collection=splitted_filter[0],
+                        attribute=splitted_filter[1],
+                        operator=operator,
+                        value=filter_value,
+                    )
+
+                # Is this a function condition
+                elif splitted_filter[2] in QueryFilterStatement.QUERY_FUNCTION_EXTENSIONS:
+
+                    return QueryFilterStatement(
+                        collection=self.collections[-1],
+                        attribute=splitted_filter[0],
+                        function=splitted_filter[2],
+                        value=filter_value,
+                    )
 
     def limit(self, count, start=-1):
         """
@@ -330,20 +407,27 @@ class Query(object):
         """
         """
 
-        if isinstance(filter_statement.value, basestring):
-            filter_string = '%s.%s %s "%s"' % (
-                self._get_collection_ident(filter_statement.collection),
-                filter_statement.attribute,
-                filter_statement.operator,
-                filter_statement.value,
-            )
-        else:
-            filter_string = '%s.%s %s %s' % (
-                self._get_collection_ident(filter_statement.collection),
-                filter_statement.attribute,
-                filter_statement.operator,
-                filter_statement.value,
-            )
+        filter_string = ''
+
+        # Operator
+        if not filter_statement.operator is None:
+            if isinstance(filter_statement.value, basestring):
+                filter_string = '%s.%s %s "%s"' % (
+                    self._get_collection_ident(filter_statement.collection),
+                    filter_statement.attribute,
+                    filter_statement.operator,
+                    filter_statement.value,
+                )
+            else:
+                filter_string = '%s.%s %s %s' % (
+                    self._get_collection_ident(filter_statement.collection),
+                    filter_statement.attribute,
+                    filter_statement.operator,
+                    filter_statement.value,
+                )
+        elif not filter_statement.function is None:
+            collection_name = self._get_collection_ident(filter_statement.collection)
+            filter_string =  filter_statement.get_filter_function_string(collection_name)
 
         return filter_string
 
@@ -357,20 +441,20 @@ class Query(object):
             collection = self.collections[0]
             return_statement += ' RETURN %s' % self._get_collection_ident(collection_name=collection)
         else:
-            colletions_string = ''
+            collections_string = ''
             is_first = True
 
             for collection in self.collections:
                 if is_first:
                     is_first = False
 
-                    colletions_string += self._get_collection_ident(collection)
+                    collections_string += self._get_collection_ident(collection)
 
                 else:
-                    colletions_string += ' , %s ' % self._get_collection_ident(collection)
+                    collections_string += ' , %s ' % self._get_collection_ident(collection)
 
 
-            return_statement += ' RETURN [ %s ]' % colletions_string
+            return_statement += ' RETURN [ %s ]' % collections_string
 
         return return_statement
 
